@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play a MIDI score in real-time
 
-our $VERSION = '0.0107';
+our $VERSION = '0.0108';
 
 use strict;
 use warnings;
@@ -27,21 +27,11 @@ sub new {
 
     $opts{device} = RtMidiOut->new;
 
-    # Linux: Timidity support requires timidity in daemon mode
-    # If your distro does not install a service, do: timidity -iAD
-    # FluidSynth is an alternative to Timidity++
     $opts{port} //= qr/wavetable|loopmidi|timidity|fluid/i;
 
-    # MacOS: You can get General MIDI via DLSMusicDevice within
-    # Logic or Garageband. You will need a soundfont containing
-    # drum patches in '~/Library/Audio/Sounds/Banks/'
-    # and DLSMusicDevice open in GarageBand / Logic with this
-    # sound front selected.
-    # DLSMusicDevice should receive input from the virtual port
-    # opened below.
-    # See MIDI::RtMidi::FFI::Device docs for more info.
+    # For MacOS, DLSMusicDevice should receive input from this virtual port:
     $opts{device}->open_virtual_port('dummy') if $^O eq 'darwin';
-    # Alternatively you can use FluidSynth
+
     $opts{device}->open_port_by_name($opts{port});
 
     bless \%opts, $class;
@@ -79,8 +69,7 @@ sub _play {
     $self->_reset_score;
 }
 
-# This manipulates internals of MIDI::Score objects and
-# hashes - doing this isn't a good idea.
+# This manipulates internals of MIDI::Score things and doing this isn't a good idea
 sub _reset_score {
     my ($self) = @_;
     # sorry
@@ -118,7 +107,7 @@ MIDI::RtMidi::ScorePlayer - Play a MIDI score in real-time
 
 =head1 VERSION
 
-version 0.0107
+version 0.0108
 
 =head1 SYNOPSIS
 
@@ -133,13 +122,17 @@ version 0.0107
       my (%args) = @_;
       ...; # Setup things
       my $treble = sub {
-          $args{score}->n('...');
-          ...; # See MIDI::Simple for the n() & r() methods
+          if ($args{_part} % 2) {
+              $args{score}->n('...');
+          }
+          else {
+              $args{score}->r('...');
+          }
       };
       return $treble;
   }
   sub bass {
-      ...; # As above
+      ...; # As above but different!
   }
 
   MIDI::RtMidi::ScorePlayer->new(
@@ -156,6 +149,20 @@ version 0.0107
 
 C<MIDI::RtMidi::ScorePlayer> plays a MIDI score in real-time.
 
+In order to use this module, create subroutines for simultaneous MIDI
+B<parts> that take a B<common> hash of named arguments. These parts
+each return an anonymous subroutine that tells MIDI-perl to build up a
+B<score>, by adding notes (C<n()>) and rests (C<r()>), etc. These
+musical operations are described in the L<MIDI> modules, like
+L<MIDI::Simple>.
+
+Besides being handed the B<common> arguments, each B<part> function
+gets a handy, increasing B<_part> number, starting at one, which can
+be used in the part functions.
+
+These parts are synch'd together, given the B<new> parameters that are
+described in the example above.
+
 =head2 Hints
 
 B<Linux>: If your distro does not install a service, you can use
